@@ -16,9 +16,11 @@
  * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
+#include <memory>
 #include <iostream>
 #include <stdexcept>
 #include <glibmm/exception.h>
+#include <glibmm/miscutils.h>
 #include "server.hpp"
 
 int main(int argc, char* argv[]) try
@@ -30,6 +32,11 @@ int main(int argc, char* argv[]) try
 	// Success, if no exception has been thrown
 	return EXIT_SUCCESS;
 }
+catch(Sobby::Server::Exit& exit)
+{
+	// Server exit
+	return EXIT_SUCCESS;
+}
 catch(std::exception& e)
 {
 	std::cerr << e.what() << std::endl;
@@ -40,4 +47,3 @@ catch(Glib::Exception& e)
 	std::cerr << e.what() << std::endl;
 	return EXIT_FAILURE;
 }
-
